@@ -260,22 +260,32 @@ func updateHelpText() {
 	if prometheusPort != "" {
 		prometheusStatus = fmt.Sprintf("Enabled (Port: %s)", prometheusPort)
 	}
-	helpText.Text = fmt.Sprintf(
+	fullText := fmt.Sprintf(
 		"mactop is open source monitoring tool for Apple Silicon authored by Carsen Klock in Go Lang!\n\n"+
 			"Repo: github.com/metaspartan/mactop\n\n"+
-			"Prometheus Metrics: %s\n\n"+
-			"Controls:\n"+
+			"----Current Settings----\n"+
+			"Prometheus Metrics: %s\n"+
+			"Version: %s\n"+
+			"Layout: %s\n"+
+			"Foreground Color: %s\n"+
+			"Background Color: %s\n"+
+			"Update Interval: %dms\n\n"+
+			"----Controls----\n"+
 			"- r: Refresh the UI data manually\n"+
 			"- c: Cycle through UI color themes\n"+
+			"- b: Cycle through UI background colors\n"+
 			"- p: Toggle party mode (color cycling)\n"+
-			"- l: Cycle through the 6 available layouts\n"+
-			"- F9: Kill selected process (y/n confirm)\n"+ // Updated text
-			"- /: Search process list\n"+ // Added help
-			"- g/G: Jump to top/bottom of process list\n"+ // Added help
+			"- l: Cycle through the 17 available layouts\n"+
+			"- i: Toggle information layout\n"+
+			"- F9: Kill selected process (y/n confirm)\n"+
+			"- f: Freeze the process list\n"+
+			"- /: Search process list\n"+
+			"- g/G: Jump to top/bottom of process list\n"+
 			"- + or -: Adjust update interval (faster/slower)\n"+
 			"- h or ?: Toggle this help menu\n"+
+			"- j/k or ↓/↑: Scroll help text\n"+ // Added scroll help
 			"- q or <C-c>: Quit the application\n\n"+
-			"Start Flags:\n"+
+			"----Start Flags----\n"+
 			"--help, -h: Show this help menu\n"+
 			"--version, -v: Show the version of mactop\n"+
 			"--interval, -i: Set the update interval in milliseconds. Default is 1000.\n"+
@@ -288,23 +298,86 @@ func updateHelpText() {
 			"--unit-network: Network unit: auto, byte, kb, mb, gb (default: auto)\n"+
 			"--unit-disk: Disk unit: auto, byte, kb, mb, gb (default: auto)\n"+
 			"--unit-temp: Temperature unit: celsius, fahrenheit (default: celsius)\n"+
-			"--color, -c: Set the UI color. Default is none. Options are 'green', 'red', 'blue', 'skyblue', 'magenta', 'yellow', 'gold', 'silver', and 'white'.\n\n"+
-			"Version: %s\n\n"+
-			"Current Settings:\n"+
-			"Layout: %s\n"+
-			"Theme: %s\n"+
-			"Update Interval: %dms",
+			"--color, -c: Set the UI color. Default is none. Options are 'green', 'red', 'blue', 'skyblue', 'magenta', 'yellow', 'gold', 'silver', and more.\n\n",
 		prometheusStatus,
 		version,
 		currentConfig.DefaultLayout,
 		currentConfig.Theme,
+		currentConfig.Background,
 		updateInterval,
 	)
+
+	lines := strings.Split(fullText, "\n")
+	_, termHeight := GetCachedTerminalDimensions()
+
+	// Determine if we need scrolling
+	// First calculate raw available height minus borders
+	rawHeight := termHeight - 2
+	if rawHeight < 1 {
+		rawHeight = 1
+	}
+
+	availableHeight := rawHeight
+	maxOffset := 0
+
+	// If content doesn't fit, we need to reserve space for indicators
+	if len(lines) > rawHeight {
+		// Reserve 2 lines (1 for top indicator/spacer, 1 for bottom indicator/spacer)
+		availableHeight = rawHeight - 2
+		if availableHeight < 1 {
+			availableHeight = 1
+		}
+		maxOffset = len(lines) - availableHeight
+	}
+
+	if helpScrollOffset > maxOffset {
+		helpScrollOffset = maxOffset
+	}
+	if helpScrollOffset < 0 {
+		helpScrollOffset = 0
+	}
+
+	start := helpScrollOffset
+	end := start + availableHeight
+	if end > len(lines) {
+		end = len(lines)
+	}
+
+	visibleLines := lines[start:end]
+
+	var finalBuilder strings.Builder
+	tc := getThemeColor()
+
+	// Top indicator (only if scrolling is active)
+	if maxOffset > 0 {
+		if helpScrollOffset > 0 {
+			fmt.Fprintf(&finalBuilder, "[↑ Scroll up (k/↑)](fg:%s)\n", tc)
+		} else {
+			finalBuilder.WriteString("\n") // Spacer
+		}
+	}
+
+	// Content
+	finalBuilder.WriteString(strings.Join(visibleLines, "\n"))
+
+	// Bottom indicator (only if scrolling is active)
+	if maxOffset > 0 {
+		if helpScrollOffset < maxOffset {
+			fmt.Fprintf(&finalBuilder, "\n[↓ Scroll down (j/↓)](fg:%s)", tc)
+		} else {
+			finalBuilder.WriteString("\n") // Spacer
+		}
+	}
+
+	helpText.Text = finalBuilder.String()
 }
 
 func toggleHelpMenu() {
-	updateHelpText()
 	showHelp = !showHelp
+	if showHelp {
+		helpScrollOffset = 0
+	}
+	updateHelpText()
 
 	renderMutex.Lock()
 	defer renderMutex.Unlock()
